Auth0 class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIdTokenClaims({GetIdTokenClaimsOptions? options}) → Future<Map<String, dynamic>?>
Calls Auth0 getIdTokenClaims method.
getTokenSilently({GetTokenSilentlyOptions? options}) → Future<String>
Calls Auth0 getTokenSilently method.
getTokenWithPopup({GetTokenWithPopupOptions? options, PopupConfigOptions? config}) → Future<String>
Calls Auth0 getTokenWithPopup method.
getUser({GetUserOptions? options}) → Future<Map<String, dynamic>?>
Calls Auth0 getUser method.
getUserInfo(String accessToken) → Future<Map<String, dynamic>?>
Calls Auth0 getUserInfo method.
handleRedirectCallback(String url) → Future<void>
isAuthenticated() → Future<bool>
Calls Auth0 isAuthenticated method.
loginWithPopup({PopupLoginOptions? options, PopupConfigOptions? config}) → Future<void>
Calls Auth0 loginWithPopup method.
loginWithRedirect({String redirectUri = ''}) → Future<String?>
Calls Auth0 loginWithRedirect method.
logout({LogoutOptions? options}) → void
Calls Auth0 logout method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited