Auth0ClientOptions class

Inheritance
Annotations

Constructors

Auth0ClientOptions({String display, String prompt, Object max_age, String ui_locales, String id_token_hint, String login_hint, String acr_values, String scope, String audience, String? connection, @required String domain, String issuer, @required String client_id, String? redirect_uri, num leeway, Object cacheLocation, bool useRefreshTokens, num authorizeTimeoutInSeconds, bool legacySameSiteCookie, bool useCookiesForTransactions, AdvancedOptions advancedOptions, num sessionCheckExpiryDays})
factory

Properties

acr_values → String
no setterinherited
advancedOptions → AdvancedOptions
no setter
audience → String
no setterinherited
authorizeTimeoutInSeconds → num
no setter
cacheLocation → Object
no setter
client_id → String
no setter
connection → String?
no setterinherited
display → String
no setterinherited
domain → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id_token_hint → String
no setterinherited
issuer → String
no setter
leeway → num
no setter
legacySameSiteCookie → bool
no setter
login_hint → String
no setterinherited
max_age → Object
no setterinherited
prompt → String
no setterinherited
redirect_uri → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
no setterinherited
sessionCheckExpiryDays → num
no setter
ui_locales → String
no setterinherited
useCookiesForTransactions → bool
no setter
useRefreshTokens → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited