BaseLoginOptions class

Implementers
Annotations

Constructors

BaseLoginOptions({String display, String prompt, Object max_age, String ui_locales, String id_token_hint, String login_hint, String acr_values, String scope, String audience, String? connection})
factory

Properties

acr_values → String
no setter
audience → String
no setter
connection → String?
no setter
display → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id_token_hint → String
no setter
login_hint → String
no setter
max_age → Object
no setter
prompt → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
no setter
ui_locales → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited