LogoutOptions class

Annotations

Constructors

LogoutOptions({String returnTo, String? client_id, bool federated, bool localOnly})
factory

Properties

client_id → String?
no setter
federated → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
localOnly → bool
no setter
returnTo → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited